@@ -1,21 +1,5 @@
 from sparrow import yaml_load
 
-def update_requirements():
-    verson_config = yaml_load('./manimlib/version-config.yaml')
-    pkg_name = verson_config.get('name')
-    version_str = verson_config.get('version')
-
-    with open('requirements.txt', 'w', encoding='utf8') as fo:
-        content = f"""
-{pkg_name} >= {version_str}
-sparrow_tool
-fake_headers
-requests
-# helium
-# pyperclip
-"""
-        fo.write(content)
-
 
 def update_setup_cfg():
     verson_config = yaml_load('./manim_express/version-config.yaml')
@@ -31,8 +15,9 @@ def update_setup_cfg():
         fio.writelines(lines)
 
 
-
-
-
 if __name__ == "__main__":
-    update_requirements()
+    from git import Repo
+
+    # update_requirements()
+    repo = Repo()
+    # print(repo.git.execute('git status'))
